Index: applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/MapdustGUI.java
===================================================================
--- applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/MapdustGUI.java	(revision 33160)
+++ applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/MapdustGUI.java	(revision 33231)
@@ -93,6 +93,9 @@
     private JPanel mainPanel;
 
-    /** Specifies if the MapDust data was or not down-loaded */
-    private boolean downloaded = false;
+    /** Specifies if the MapDust data was or not downloaded */
+    private boolean downloaded;
+
+    /** Remembers if the dialog has been destroyed */
+    private boolean destroyed;
 
     /**
@@ -152,5 +155,8 @@
         downloaded = false;
         button.setSelected(false);
-        super.destroy();
+        if (!destroyed) {
+            super.destroy();
+            destroyed = true;
+        }
     }
 
